@@ -1,30 +1,20 @@
 """Access parquet datasets using pyarrow.
 """
-import collections
+import collections.abc
 import random
 import re
 import shutil
 from pathlib import Path
 from typing import Dict, Iterable, List, Union
 
+import pandas as pd
+import pyarrow as pa
+import pyarrow.parquet as pq
+
 import dframeio.filter
 
 from .abstract import AbstractDataFrameReader, AbstractDataFrameWriter
 
-try:
-    import pandas as pd
-except ImportError:
-    pd = None
-
-try:
-    import pyarrow as pa
-    import pyarrow.parquet as pq
-except ModuleNotFoundError as e:
-    if e.name == "pyarrow":
-        pq = None
-    else:
-        raise
-
 
 class ParquetBackend(AbstractDataFrameReader, AbstractDataFrameWriter):
     """Backend to read and write parquet datasets
@@ -108,6 +98,8 @@ class ParquetBackend(AbstractDataFrameReader, AbstractDataFrameWriter):
         df = self._read_parquet_table(
             full_path, columns=columns, row_filter=row_filter, limit=limit, sample=sample
         )
+        if drop_duplicates:
+            return df.to_pandas().drop_duplicates()
         return df.to_pandas()
 
     def read_to_dict(
@@ -127,17 +119,19 @@ class ParquetBackend(AbstractDataFrameReader, AbstractDataFrameWriter):
             row_filter: Filter expression for selecting rows
             limit: Maximum number of rows to return (limit to first n rows)
             sample: Size of a random sample to return
-            drop_duplicates: Whether to drop duplicate rows
+            drop_duplicates: (Not supported!) Whether to drop duplicate rows
 
         Returns:
             A dictionary with column names as key and a list with column values as values
 
         Raises:
-            NotImplementedError: If row_filter is given, because this is not yet implemented
+            NotImplementedError: When drop_duplicates is specified
 
         The logic of the filtering arguments is as documented for
         [`AbstractDataFrameReader.read_to_pandas()`](dframeio.abstract.AbstractDataFrameReader.read_to_pandas).
         """
+        if drop_duplicates:
+            raise NotImplementedError("drop_duplicates not available for Parquet -> dict")
         full_path = self._validated_full_path(source)
         df = self._read_parquet_table(
             full_path, columns=columns, row_filter=row_filter, limit=limit, sample=sample
@@ -202,7 +196,7 @@ class ParquetBackend(AbstractDataFrameReader, AbstractDataFrameWriter):
         if full_path.exists() and full_path.is_file():
             if isinstance(dataframe, pd.DataFrame):
                 dataframe = pd.concat([self.read_to_pandas(str(full_path)), dataframe])
-            elif isinstance(dataframe, collections.Mapping):
+            elif isinstance(dataframe, collections.abc.Mapping):
                 old_data = self._read_parquet_table(
                     str(full_path), use_pandas_metadata=False
                 ).to_pydict()
@@ -258,7 +252,7 @@ class ParquetBackend(AbstractDataFrameReader, AbstractDataFrameWriter):
                 )
 
     @staticmethod
-    def _remove_matching_keys(d: collections.Mapping, regex: str):
+    def _remove_matching_keys(d: collections.abc.Mapping, regex: str):
         """Remove all keys matching regex from the dictionary d"""
         compiled_regex = re.compile(regex)
         keys_to_delete = [k for k in d.keys() if compiled_regex.match(k)]
@@ -277,7 +271,7 @@ class ParquetBackend(AbstractDataFrameReader, AbstractDataFrameWriter):
         """
         if isinstance(dataframe, pd.DataFrame):
             return len(dataframe)
-        if isinstance(dataframe, collections.Mapping):
+        if isinstance(dataframe, collections.abc.Mapping):
             return len(next(iter(dataframe.values())))
         raise TypeError("dataframe must be a pandas.DataFrame or dict")
 
@@ -287,7 +281,7 @@ class ParquetBackend(AbstractDataFrameReader, AbstractDataFrameWriter):
     ):
         if isinstance(dataframe, pd.DataFrame):
             return pa.Table.from_pandas(dataframe.iloc[start:stop], preserve_index=True)
-        if isinstance(dataframe, collections.Mapping):
+        if isinstance(dataframe, collections.abc.Mapping):
             return pa.Table.from_pydict(
                 {colname: col[start:stop] for colname, col in dataframe.items()}
             )
@@ -312,13 +306,13 @@ class ParquetBackend(AbstractDataFrameReader, AbstractDataFrameWriter):
         """Convert the dataframe to an arrow table"""
         if isinstance(dataframe, pd.DataFrame):
             return pa.Table.from_pandas(dataframe, preserve_index=True)
-        if isinstance(dataframe, collections.Mapping):
+        if isinstance(dataframe, collections.abc.Mapping):
             return pa.Table.from_pydict(dataframe)
         raise ValueError("dataframe must be a pandas.DataFrame or dict")
 
     @staticmethod
     def _read_parquet_table(
-        full_path: str,
+        full_path: Union[str, Path],
         columns: List[str] = None,
         row_filter: str = None,
         limit: int = -1,
