@@ -4,8 +4,9 @@ from pathlib import Path
 
 import pandas as pd
 import pandera as pa
+import pandera.typing
 import pytest
-from pandas.util.testing import assert_frame_equal
+from pandas.testing import assert_frame_equal
 
 import dframeio
 
@@ -14,7 +15,7 @@ class SampleDataSchema(pa.SchemaModel):
     """pandera schema of the parquet test dataset"""
 
     registration_dttm: pa.typing.Series[pa.typing.DateTime]
-    id: pa.typing.Series[pa.typing.Int] = pa.Field(nullable=True)
+    id: pa.typing.Series[pd.Int64Dtype] = pa.Field(nullable=True, coerce=True)
     first_name: pa.typing.Series[pa.typing.String]
     last_name: pa.typing.Series[pa.typing.String]
     email: pa.typing.Series[pa.typing.String]
